      subroutine convolbesl0(fr,gr,ofr,ogr,nblk8,t)
c     ****************************************************************
c
c     does the conbolution using the bessel function expansion of exp.
c
c     ****************************************************************
      implicit none
 
      real*8 fr(200), gr(200), ofr(200), ogr(200),t
      integer*4 nblk8
      
      include 'mai1_com.inc'
      include 'vcinp_com.inc'
c      include 'sept_com.inc'
      include 'lamx_com.inc'
      include 'pi_com.inc'

      real*8 mu,mu1,ma,newtfac
      integer*4 iz(200),ifac(12),ibad(12),npo,il,i,jj,indic,j,k
c      integer*4 ilmax,ilo
      integer*4 ir,ii,npx
      real*8 cho(11), tho(11),big(200),bag(8)
      real*8 z(200),bes(200,200),dup(12),cxp(200)
      real*8 axp(200),bxp(200),r(200),rprim(200),r2(200)
      real*8 rprim2(200),theta(200),cprim(200)    
      real*8 dx,quatpi,pimu,sqpimu,fnorm,rj,ra,rfac,rbad,term
      real*8 expo,ta,tb,ca,cb,signe,soms,somv
  
      real*8 sdot,ssum

c     coeff. integ. open newton-cotes  8 pts see Abramowitz & Stegun, Dover
      data bag/0.,460.,-954.,2196.,-2459.,2196.,-954.,460./ 


      npo=8*nblk8

      il=0
      quatpi=4.0d0*pi
      dx= 0.1
      mu=t**2
      mu1=1.d0/mu
      pimu=mu*pi
c      sqpimu=dsqrt(pimu)
      sqpimu=dsqrt(pi*mu)
      fnorm=quatpi/(sqpimu**3)
      newtfac=8.d0*dx/945.d0

c     preparation of the arrays
      do i=1,199                                           
         iz(i)=i                                                 
         indic=mod(i,8)+1                                        
         big(i+1)=bag(indic) 
         r(i)=(dfloat(i)-.1d0)*dx   
         rprim(i)=(dfloat(i)-0.0d0)*h     
         r2(i)=mu1*r(i)**2                              
         rprim2(i)=mu1*rprim(i)**2    
         axp(i)=r2(i)
         theta(i)=1.                          
      enddo      
      do i=120,160
         theta(i)=dexp(-120.d0)
         axp(i)=r2(i)-120.d0
         rprim2(i)=rprim2(i)-120.d0
      enddo
      do i=1,160
         cxp(i)=dexp(-axp(i))
         cprim(i)=dexp(-rprim2(i))
      enddo
 
      do i=1,8
         cho(i)=0.0d0
         tho(i)=0.0d0
      enddo
      if (il.eq.0) then
           cho(1)=1.0d0
           tho(1)=-1.0d0
      else
         write(6,*) 'Only for spherical nuclei'
         stop
      endif
         
      ibad(1)=2*il+3
      ifac(1)=1
      jj=1
      do i=2,5
         ifac(i)=ifac(i-1)*i
         ibad(i)=ibad(i-1)*(2*il+2*i+1)
      enddo
      do i=1,il
         jj=jj*(2*iz(i)+1)
      enddo
      rj=dfloat(jj)

c     calculate the bessel fct.
      do j=1,npts
         do i=2,npo
           z(i)=2*r(i)*rprim(j)*mu1
           if(z(i).le.0.1d0) then
              ra=1.d0
              signe=-1.d0
              do ir=1,3
                 rfac=dfloat(ifac(ir))
                 rbad=dfloat(ibad(ir))
                 term=(-0.5d0*z(i)**2)**ir/(rfac*rbad)
                 if(dabs(term).lt.1.d-70)term=0.d0
                 ra=ra+term*signe
                 signe=-signe
              enddo
              bes(i,j)=ra*(z(i)**il)/rj
           else
              expo=0.
              if(z(i).ge.170.d0)then
                 expo=-150.
                 z(i)=z(i)-150.d0
              endif
              axp(i)=dexp(z(i))
              bxp(i)=1./axp(i)
              if(expo.eq.-150.)z(i)=z(i)+150.d0
              do ii=1,il+1
                 dup(ii)=z(i)**(-iz(ii))
              enddo
              ta=sdot(il+1,cho(1),1,dup(1),1)
              tb=sdot(il+1,tho(1),1,dup(1),1)
              ca=ta*axp(i)*dexp(-expo)
              cb=tb*bxp(i)*dexp(expo)
              bes(i,j)=0.5d0*(ca+cb)
              if(dabs(bes(i,j)).lt.1.d-70) bes(i,j)=0.d0
           endif
         enddo
      enddo

c     folding 
      npx=npo-1
      do j=1,npts
         ma=theta(j)*mu
         do k=2,npo
            axp(k)=bes(k,j)*r2(k)*big(k)*cxp(k)*theta(k)*fr(k)
            bxp(k)=bes(k,j)*r2(k)*big(k)*cxp(k)*theta(k)*gr(k)
         enddo
         soms=ssum(npx,axp(2),1)
         somv=ssum(npx,bxp(2),1)
         ofr(j)=soms*newtfac*fnorm*cprim(j)*ma
         ogr(j)=somv*newtfac*fnorm*cprim(j)*ma
      enddo

      return
      end
